# Add Applications
### On this page
  * [Introduction to Applications](https://help.sap.com/docs/leanix/ea/add-applications#introduction-to-applications)
  * [Required Attributes](https://help.sap.com/docs/leanix/ea/add-applications#required-attributes)
  * [Collect Application Data](https://help.sap.com/docs/leanix/ea/add-applications#collect-application-data)
  * [Add Applications](https://help.sap.com/docs/leanix/ea/add-applications#add-applications)
  * [Scope Applications](https://help.sap.com/docs/leanix/ea/add-applications#scope-applications)
  * [Monitor Progress Using Metrics](https://help.sap.com/docs/leanix/ea/add-applications#monitor-progress-using-metrics)


Import an initial set of applications into your workspace. Applications are essential elements of your enterprise architecture landscape.
